@@ -518,9 +518,17 @@ class Connection:
         status_response = self.do_get_request(self.status_url)
         return utils.parse_json_response(status_response)
 
-    def get_datasets(self):
+    def get_datasets(self, include_internal_datasets=True, verbose=False):
+        # Note: the default for getting datasets is to get all
+        # including the internal ones
+        # This is opposite behaviour to pipes/systems
         datasets = []
-        response = self.do_get_request(self.datasets_url, allowable_response_status_codes=[200])
+        params = {}
+        if not include_internal_datasets:
+            params["include-internal-datasets"] = include_internal_datasets
+        if verbose:
+            params["verbose"] = verbose
+        response = self.do_get_request(self.datasets_url, allowable_response_status_codes=[200], params=params)
         parsed_response = utils.parse_json_response(response)
         for dataset_json in parsed_response:
             datasets.append(Dataset(self, dataset_json))
